..
   This is an autogenerated file from processors.rst

avatars.processors.InterRecordBoundedCumulatedDifferenceProcessor
=================================================================

.. autoclass:: avatars.processors.InterRecordBoundedCumulatedDifferenceProcessor
   :members: